/*
   =======================================================================================================

   IRTFIT Example code  (Version 1.0 12/20/06)

   This file contains SAS syntax for running the examples from the IRTFIT manual.
   This code will run assuming that you have placed the example datasets and the compiled
   macrolibrary in the directory c:\irtfit\examples and that you run the libname and options
   statements that appear below to set up the appropriate libraries ahead of time.
   
   You must read and agree to the following disclaimer before using this software.

   DISCLAIMER:
   THIS INFORMATION IS PROVIDED BY QUALITYMETRIC INCORPORATED AS A SERVICE TO THE RESEARCH COMMUNITY.
   IT IS PROVIDED "AS IS."  THERE ARE NO WARRANTIES, EXPRESSED OR IMPLIED, AS TO MERCHANTABILITY OR
   FITNESS FOR A PARTICULAR PURPOSE, OR REGARDING THE ACCURACY OF THE MATERIALS OR CODE CONTAINED HEREIN.

   =======================================================================================================

*/


/* LIBRARY CODE:  RUN FIRST! */

     Libname example 'c:\irtfit\examples';
     options mstored sasmstore=example;

	 run;



/* Example 1: Generalized Partial Credit Model */

     %IRTFIT(DATA = example.sumexaple
	,   PARFILE = example.sumexamplepar
	,  ITEMLIST = it6-it10
	,TESTMETHOD = sum
	,     GRAPH = yes
	,    OUTFMT = rtf
	,    OUTLIB = c:\irtfit\examples
	,   OUTCORE = five_sgpcm
	);
     run;


/* Example 2: Dichotomous Model */

     %IRTFIT(DATA = example.sumdiexample
	,   PARFILE = example.sumdiexaplepar
	,  ITEMLIST = it1-it5
	,TESTMETHOD = sum
	,     SCALE = total
	,   MINCODE = 0
	,     GRAPH = yes
	,    OUTFMT = rtf
	,    OUTLIB = c:\irtfit\examples
	,   OUTCORE = five_sdi
	);
     run;


/* Example 3: Generalized Partial Credit Model based on THETA method (without graphs) */

     %IRTFIT(DATA = example.thetaexample
	,    PARFILE = example.thetaexamplepar
	,   ITEMLIST = it6-it10
	, TESTMETHOD = theta
	,     OUTFMT = rtf
	,    OUTLIB = c:\irtfit\examples
	,   OUTCORE = five_t
	);
     run;



/* Example 4: Dichotomous and Nominal Models (in one file) based on THETA method (without graphs) */

     %IRTFIT(DATA = example.dinomexample
	,    PARFILE = example.dinomexamplepar
	,   ITEMLIST = it1-it12
	, TESTMETHOD = theta
	,      SCALE = total
	,     OUTFMT = rtf
	,    OUTLIB = c:\irtfit\examples
	,   OUTCORE = twelve_di_nom
	);
     run;


/* Example 5: Graphical outputs only (on output from example 3) */

     %IRTFIT(GRAPH_DATA = example.five_t_freq
	,   ITEMLIST = it6-it10
	, TESTMETHOD = NONE
	,    LD_TEST = NO
	,      GRAPH = yes
	,     OUTFMT = rtf
	,    OUTLIB = c:\irtfit\examples
	,   OUTCORE = five_t_graph
	);
     run;



/* Example 6: Test for local dependence (without graphs) */

     %IRTFIT(DATA = example.ldexample
	,    PARFILE = example.ldexamplepar
	,   ITEMLIST = it6-it10
	, TESTMETHOD = NONE
	,    LD_TEST = YES
	,     OUTFMT = rtf
	,    OUTLIB = c:\irtfit\examples
	,   OUTCORE = five_ld
	);
     run;



/* End of IRTFIT Examples */
